translateToOriginPoint method
Translates the coordinates from center to origin coordinates (based on the object's dimensions)
Implementation
external Point translateToOriginPoint(
Point center, String originX, String originY);
Translates the coordinates from center to origin coordinates (based on the object's dimensions)
external Point translateToOriginPoint(
Point center, String originX, String originY);